@@ -52,6 +52,9 @@ class Lookup : public QWidget
     QPushButton       *m_queryButton;
     int               m_queryType;
     QSignalMapper     *m_signalMapper;
+public slots:
+    void unbusy();
+    void busy();
 };
 
 #endif
